@@ -1,7 +1,13 @@
 """ Module w.r.t. Azure table storage logic."""
 
+from azure.core.exceptions import (
+    HttpResponseError,
+    ServiceResponseError,
+    ServiceResponseTimeoutError,
+)
 from azure.data.tables import TableServiceClient
 
+from warpzone.healthchecks import HealthCheckResult, HealthStatus
 from warpzone.tablestorage.operations import TableOperations
 
 
@@ -58,3 +64,28 @@ class WarpzoneTableClient:
         entities = [record for record in table_client.query_entities(query)]
 
         return entities
+
+    def check_health(self) -> HealthCheckResult:
+        """
+        Pings the connection to the client's associated table storage in Azure.
+        """
+
+        try:
+            table_iterator = self._table_service_client.list_tables()
+            next(table_iterator, None)
+        except (
+            ServiceResponseError,
+            ServiceResponseTimeoutError,
+            HttpResponseError,
+            # An unhandled bug in Azure causes an AttributeError to be raised
+            # when authentication fails. Once fixed, this can be removed.
+            # See https://github.com/Azure/azure-sdk-for-python/issues/21416
+            AttributeError,
+        ) as ex:
+            return HealthCheckResult(
+                status=HealthStatus.UNHEALTHY,
+                description="Unable to connect to table storage.",
+                exception=ex,
+            )
+
+        return HealthCheckResult.healthy()
